TypeIdIndexMap

Type Alias TypeIdIndexMap 

pub type TypeIdIndexMap<V> = IndexMap<TypeId, V, NoOpHash>;
A specialized index map type with a key of TypeId. Iteration order only depends on the order of insertions and deletions.

Aliased Type

pub struct TypeIdIndexMap<V> { /* private fields */ }