pub type TypeIdIndexMap<V> = IndexMap<TypeId, V, NoOpHash>;Expand description
A specialized index map type with a key of TypeId.
Iteration order only depends on the order of insertions and deletions.
Aliased Type
pub struct TypeIdIndexMap<V> { /* private fields */ }